pub enum SourceChainCursor {
Sequence(u32),
ActionHash(HoloHash<Action>),
}Expand description
Identifies the last source-chain record returned by a paginated dump.
The next page starts strictly after the identified record.
Variants
Sequence(u32)
Resume after this action sequence number.
ActionHash(HoloHash<Action>)
Resume after the accepted action identified by this hash.