pub struct AgentInfoDump {
pub kitsune_agent: Arc<AgentId>,
pub kitsune_space: Arc<SpaceId>,
pub dump: String,
}Expand description
Agent info dump with the agent, space, signed time, expires in and urls printed in a pretty way.
Fields
kitsune_agent: Arc<AgentId>kitsune_space: Arc<SpaceId>dump: StringTrait Implementations
Sourceimpl Clone for AgentInfoDump
impl Clone for AgentInfoDump
Sourcefn clone(&self) -> AgentInfoDump
fn clone(&self) -> AgentInfoDump
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentInfoDump
impl Debug for AgentInfoDump
Sourceimpl<'de> Deserialize<'de> for AgentInfoDump
impl<'de> Deserialize<'de> for AgentInfoDump
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AgentInfoDump, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AgentInfoDump, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for AgentInfoDump
impl Display for AgentInfoDump
impl Eq for AgentInfoDump
Sourceimpl PartialEq for AgentInfoDump
impl PartialEq for AgentInfoDump
Sourceimpl Serialize for AgentInfoDump
impl Serialize for AgentInfoDump
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for AgentInfoDump