pub struct AppAuthenticationTokenIssued {
pub token: Vec<u8>,
pub expires_at: Option<Timestamp>,
}Expand description
Response payload for AdminResponse::AppAuthenticationTokenIssued.
Fields
token: Vec<u8>A token issued by the conductor that can be used to authenticate a connection to an app interface. This is expected to be passed from the caller of the admin interface to the client that will use the app interface. It should be treated as secret and kept from other parties.
expires_at: Option<Timestamp>The timestamp after which Holochain will consider the token invalid. This should be considered informational only and the client should not rely on the token being accepted following a client-side check that the token has not yet expired.
If the token was created with IssueAppAuthenticationTokenPayload::expiry_seconds set to 0
then this field will be None.