pub struct FullIntegrationStateDump {
pub validation_limbo: Vec<DhtOp>,
pub integration_limbo: Vec<DhtOp>,
pub integrated: Vec<DhtOp>,
pub dht_ops_cursor: Option<DhtOpsCursor>,
}Expand description
A full view of the DHT shard of the Cell. Ops start in the validation limbo then proceed to the integration limbo then finally are integrated.
Fields
validation_limbo: Vec<DhtOp>Ops in validation limbo awaiting sys or app validation.
integration_limbo: Vec<DhtOp>Ops waiting to be integrated.
integrated: Vec<DhtOp>Ops that are integrated (includes rejected).
dht_ops_cursor: Option<DhtOpsCursor>Cursor marking the last DHT op selected across all lifecycle buckets.
Pass it to a subsequent FullStateDump to resume strictly after it.
None when the page selected no DHT ops.