Module interface

Module interface 

Interfaces are long-running tasks which listen for incoming messages and dispatch them to the appropriate handlers within Holochain. They also allow emitting responses and one-way Signals.

Currently, the only InterfaceDriver is a Websocket-based one, whose implementation can be found in the websocket module here.

Modules

error
Custom error type for the Holochain interface.
websocket
Module for establishing Websocket-based Interfaces, i.e. those configured with InterfaceDriver::Websocket

Enums

InterfaceDriver
Configuration for interfaces, specifying the means by which an interface should be opened.