pub enum ActivityRequest {
Status,
Full,
}Expand description
When calling hdk::chain::get_agent_activity, specify whether to get either a
summary of the chain’s status, or a summary plus the hashes of the chain
actions that match the given ChainQueryFilter. See the notes on
AgentActivityStatus about the perspective-dependent nature of the agent’s
status and valid/rejected activity.
Variants
Status
Just request a summary consisting of the status of the chain,
the highest observed chain action, and any Warrants collected
for the agent.
Full
Request the status summary plus the hashes of all valid and invalid chain actions matching the filter.