MigrationTarget

Enum MigrationTarget 

pub enum MigrationTarget {
    Dna(HoloHash<Dna>),
    Agent(HoloHash<Agent>),
}
Description of how to find the previous or next CellId in a migration. In a migration, of the two components of the CellId (dna and agent), always one stays fixed while the other one changes. This enum represents the component that changed.

When used in CloseChain, this contains the new DNA hash or Agent key. When used in OpenChain, this contains the previous DNA hash or Agent key.

Variants



Dna(HoloHash<Dna>)

Represents a DNA migration, and contains the new or previous DNA hash.



Agent(HoloHash<Agent>)

Represents an Agent migration, and contains the new or previous Agent key.