pub struct AppRoleResolution {
pub dnas_to_register: Vec<(DnaFile, Option<Arc<SerializedBytes>>)>,
pub role_assignments: Vec<(String, AppRoleAssignment)>,
}Expand description
The answer to the question: “how do we concretely assign DNAs to the open roles of this App?” Includes the DNAs selected to fill the roles and the details of the role assignments.
Fields
dnas_to_register: Vec<(DnaFile, Option<Arc<SerializedBytes>>)>role_assignments: Vec<(String, AppRoleAssignment)>Implementations
Sourceimpl AppRoleResolution
impl AppRoleResolution
Sourcepub fn cells_to_create(
&self,
agent_key: HoloHash<Agent>,
) -> Vec<(CellId, Option<Arc<SerializedBytes>>)>
pub fn cells_to_create( &self, agent_key: HoloHash<Agent>, ) -> Vec<(CellId, Option<Arc<SerializedBytes>>)>
Return the IDs of new cells to be created as part of the resolution. Does not return existing cells to be reused.