pub struct ChainFilter<H = HoloHash<Action>>{
pub chain_top: H,
pub limit_conditions: LimitConditions<H>,
pub include_cached_entries: bool,
}Expand description
Filter the contiguous chain of actions from an agent’s source chain.
Starting from a specified chain_top ActionHash, the filter walks backwards through
the linear chain path, towards genesis, excluding any forked actions, and bounded by
the specified LimitConditions.
Fields
chain_top: HThe starting position of the filter.
limit_conditions: LimitConditions<H>The limit conditions used by this filter.
Defaults to LimitConditions::ToGenesis.
include_cached_entries: boolShould the query return any entries that are cached at the agent activity to save network hops.
Implementations
Sourceimpl<H> ChainFilter<H>
impl<H> ChainFilter<H>
Sourcepub fn new(chain_top: H) -> ChainFilter<H>
pub fn new(chain_top: H) -> ChainFilter<H>
Create a new filter using this ActionHash as
the starting position and walking the chain
towards the genesis Action.
Sourcepub fn take(chain_top: H, n: u32) -> ChainFilter<H>
pub fn take(chain_top: H, n: u32) -> ChainFilter<H>
Create a filter with a take limit.
Sourcepub fn include_cached_entries(self) -> ChainFilter<H>
pub fn include_cached_entries(self) -> ChainFilter<H>
Set this filter to include any cached entries at the agent activity authority.
Sourcepub fn until_timestamp(chain_top: H, timestamp: Timestamp) -> ChainFilter<H>
pub fn until_timestamp(chain_top: H, timestamp: Timestamp) -> ChainFilter<H>
Create a filter with an until-timestamp limit.
Sourcepub fn until_hash(chain_top: H, action_hash: H) -> ChainFilter<H>
pub fn until_hash(chain_top: H, action_hash: H) -> ChainFilter<H>
Create a filter with an until-hash limit.
Sourcepub fn get_until_hash(&self) -> Option<&H>
pub fn get_until_hash(&self) -> Option<&H>
Get the until hash if there is one.
Sourcepub fn get_until_timestamp(&self) -> Option<Timestamp>
pub fn get_until_timestamp(&self) -> Option<Timestamp>
Get the take number if there is one.