CounterSigningAgentState

Struct CounterSigningAgentState 

pub struct CounterSigningAgentState { /* private fields */ }
Every countersigning agent must sign against their chain state. The chain must be frozen until each agent decides to sign or exit the session.

Implementations

Source

impl CounterSigningAgentState

pub fn new( agent_index: u8, chain_top: HoloHash<Action>, action_seq: u32, ) -> CounterSigningAgentState

Constructor.

pub fn agent_index(&self) -> &u8

Agent index accessor.

pub fn agent_index_mut(&mut self) -> &mut u8

Mutable agent index accessor for testing.

pub fn chain_top(&self) -> &HoloHash<Action>

Chain top accessor.

pub fn chain_top_mut(&mut self) -> &mut HoloHash<Action>

Mutable chain top accessor for testing.

pub fn action_seq(&self) -> &u32

Action seq accessor.

pub fn action_seq_mut(&mut self) -> &mut u32

Mutable action seq accessor for testing.