pub struct CreateCloneCellPayload {
pub role_name: String,
pub modifiers: DnaModifiersOpt<YamlProperties>,
pub membrane_proof: Option<Arc<SerializedBytes>>,
pub name: Option<String>,
}Expand description
The parameters to create a clone of an existing cell.
Fields
role_name: StringThe DNA’s role name to clone
modifiers: DnaModifiersOpt<YamlProperties>Modifiers to set for the new cell. At least one of the modifiers must be set to obtain a distinct hash for the clone cell’s DNA.
membrane_proof: Option<Arc<SerializedBytes>>Optionally set a proof of membership for the clone cell
name: Option<String>Optionally a name for the DNA clone