QueryFilter

Struct QueryFilter 

pub struct QueryFilter {
    pub sequence_range: ChainQueryFilterRange,
    pub entry_type: Option<Vec<EntryType>>,
    pub entry_hashes: Option<HashSet<HoloHash<Entry>>>,
    pub action_type: Option<Vec<ActionType>>,
    pub include_entries: bool,
    pub order_descending: bool,
}
Specifies arguments to a query of the source chain, including ordering and filtering. This is used by both hdk::chain::query and hdk::chain::get_agent_activity, although the latter function ignores it if ActivityRequest::Status is used.

This struct is used to construct an actual SQL query on the database, and also has methods to allow filtering in-memory.

Fields

sequence_range: ChainQueryFilterRange

Limit the results to a range of records according to their actions.

entry_type: Option<Vec<EntryType>>

Filter by a list of EntryTypes.

entry_hashes: Option<HashSet<HoloHash<Entry>>>

Filter by a set of EntryHashes.

action_type: Option<Vec<ActionType>>

Filter by a list of ActionTypes.

include_entries: bool

Include the entries for the actions.

The source of chain data being used must include entries. When used with hdk::chain::get_agent_activity, or when invoking one of the helper methods on ChainQueryFilter that can be used with a vector of actions, this value is unused because the entry data isn’t available.

order_descending: bool

The query should be ordered in descending order (default is ascending), when run as a database query. There is no provisioning for in-memory ordering.

Implementations

Source

impl ChainQueryFilter

pub fn new() -> ChainQueryFilter

Create a no-op ChainQueryFilter which returns everything.

pub fn sequence_range( self, sequence_range: ChainQueryFilterRange, ) -> ChainQueryFilter

Filter on sequence range.

pub fn entry_type(self, entry_type: EntryType) -> ChainQueryFilter

Filter on entry type. This function can be called multiple times to create an OR query on all provided entry types.

pub fn entry_hashes( self, entry_hashes: HashSet<HoloHash<Entry>>, ) -> ChainQueryFilter

Filter on entry hashes.

pub fn action_type(self, action_type: ActionType) -> ChainQueryFilter

Filter on action type. This function can be called multiple times to create an OR query on all provided action types.

pub fn include_entries(self, include_entries: bool) -> ChainQueryFilter

Include the entries for the actions. The source of chain data being used must include entries – when used with hdk::chain::get_agent_activity, or when invoking one of the helper methods on ChainQueryFilter that can be used with a vector of actions, this value is unused because the entry data isn’t available.

pub fn ascending(self) -> ChainQueryFilter

Set the order to ascending.

pub fn descending(self) -> ChainQueryFilter

Set the order to ascending.

pub fn disambiguate_forks<T>(&self, actions: Vec<T>) -> Vec<T>

If the sequence range supports fork disambiguation, apply it to remove actions that are not in the correct branch.

Numerical range bounds do NOT support fork disambiguation, and neither does unbounded, but everything hash bounded does.

pub fn filter_actions<T>(&self, actions: Vec<T>) -> Vec<T>

Filter a vector of hashed actions according to the query.

pub fn filter_records(&self, records: Vec<Record>) -> Vec<Record>

Filter a vector of records according to the query.

A Record is an ActionHashedContainer, so this is just Self::filter_actions specialised to records.