pub struct VerifySignature {
pub key: HoloHash<Agent>,
pub signature: Signature,
pub data: Vec<u8>,
}Expand description
Mirror struct for Sign that includes a signature to verify against a key and data.
Fields
key: HoloHash<Agent>The public key associated with the private key that should be used to verify the signature.
signature: SignatureThe signature being verified.
data: Vec<u8>The signed data
Implementations
Sourceimpl VerifySignature
impl VerifySignature
Sourcepub fn as_data_ref(&self) -> &[u8] ⓘ
pub fn as_data_ref(&self) -> &[u8] ⓘ
Alias for as_ref for data.
Sourcepub fn as_signature_ref(&self) -> &Signature
pub fn as_signature_ref(&self) -> &Signature
Alias for as_ref for signature.
Sourcepub fn as_key_ref(&self) -> &HoloHash<Agent>
pub fn as_key_ref(&self) -> &HoloHash<Agent>
Alias for as_ref for agent key.
Sourcepub fn new<D>(
key: HoloHash<Agent>,
signature: Signature,
data: D,
) -> Result<VerifySignature, SerializedBytesError>
pub fn new<D>( key: HoloHash<Agent>, signature: Signature, data: D, ) -> Result<VerifySignature, SerializedBytesError>
construct a new VerifySignature struct.