pub struct WaitFor { /* private fields */ }Expand description
Generic waiting for some test property to be true. This allows early exit from waiting when the condition becomes true but will wait up to a maximum if the condition is not true.
Implementations