pub async fn spawn_app_interface_task(
tm: TaskManagerClient,
port: u16,
danger_bind_addr: Option<String>,
allowed_origins: AllowedOrigins,
installed_app_id: Option<InstalledAppId>,
api: AppInterfaceApi,
app_broadcast: AppBroadcast,
) -> InterfaceResult<u16>Expand description
Create an App Interface, which includes the ability to receive signals from Cells via a broadcast channel