pub enum Entry {
Agent(HoloHash<Agent>),
App(AppEntryBytes),
CounterSign(Box<CounterSigningSessionData>, AppEntryBytes),
CapClaim(CapClaim),
CapGrant(ZomeCallCapGrant),
}Expand description
Structure holding the entry portion of a chain record.
Variants
Agent(HoloHash<Agent>)
The Agent system entry, the third entry of every source chain,
which grants authoring capability for this agent.
App(AppEntryBytes)
The application entry data for entries that aren’t system created entries
CounterSign(Box<CounterSigningSessionData>, AppEntryBytes)
Application entry data for entries that need countersigning to move forward multiple chains together.
CapClaim(CapClaim)
The capability claim system entry which allows committing a granted permission for later use
CapGrant(ZomeCallCapGrant)
The capability grant system entry which allows granting of application defined capabilities
Implementations
Sourceimpl Entry
impl Entry
Sourcepub fn as_cap_grant(&self) -> Option<CapGrant>
pub fn as_cap_grant(&self) -> Option<CapGrant>
If this entry represents a capability grant, return a CapGrant.
Sourcepub fn as_cap_claim(&self) -> Option<&CapClaim>
pub fn as_cap_claim(&self) -> Option<&CapClaim>
If this entry represents a capability claim, return a CapClaim.
Sourcepub fn as_app_entry(&self) -> Option<&AppEntryBytes>
pub fn as_app_entry(&self) -> Option<&AppEntryBytes>
If this entry represents an App entry, return AppEntryBytes.
Sourcepub fn app(sb: SerializedBytes) -> Result<Entry, EntryError>
pub fn app(sb: SerializedBytes) -> Result<Entry, EntryError>
Create an Entry::App from SerializedBytes
Sourcepub fn app_fancy<SB>(sb: SB) -> Result<Entry, EntryError>
pub fn app_fancy<SB>(sb: SB) -> Result<Entry, EntryError>
Create an Entry::App from SerializedBytes
Sourcepub fn entry_type(&self, entry_def: Option<AppEntryDef>) -> Option<EntryType>
pub fn entry_type(&self, entry_def: Option<AppEntryDef>) -> Option<EntryType>
Get an EntryType based on the type of this Entry. If the entry type is Entry, and no entry def is specified, return None