pub enum RecordEntry<E = Entry>{
Present(E),
Hidden,
NA,
NotStored,
}Expand description
Represents the different ways the entry_address reference within an action can be interpreted
Variants
Present(E)
The Action has an entry_address reference, and the Entry is accessible.
Hidden
The Action has an entry_address reference, but we are in a public context and the entry is private.
NA
The Action does not contain an entry_address reference, so there will never be an associated Entry.
NotStored
Implementations
Sourceimpl<E> RecordEntry<E>
impl<E> RecordEntry<E>
Sourcepub fn new(
vis: Option<&EntryVisibility>,
maybe_entry: Option<E>,
) -> RecordEntry<E>
pub fn new( vis: Option<&EntryVisibility>, maybe_entry: Option<E>, ) -> RecordEntry<E>
Constructor based on Action data
Sourcepub fn as_option(&self) -> Option<&E>
pub fn as_option(&self) -> Option<&E>
Provides entry data by reference if it exists
Collapses the enum down to the two possibilities of extant or nonextant Entry data
Sourcepub fn into_option(self) -> Option<E>
pub fn into_option(self) -> Option<E>
Provides entry data as owned value if it exists.
Collapses the enum down to the two possibilities of extant or nonextant Entry data
Sourcepub fn to_app_option<A>(&self) -> Result<Option<A>, SerializedBytesError>
pub fn to_app_option<A>(&self) -> Result<Option<A>, SerializedBytesError>
Provides deserialized app entry if it exists
same as as_option but handles deserialization anything other than RecordEntry::Present returns None a present entry that fails to deserialize cleanly is an error a present entry that deserializes cleanly is returned as the provided type A
Sourcepub fn as_ref<'a>(&'a self) -> RecordEntry<&'a E>
pub fn as_ref<'a>(&'a self) -> RecordEntry<&'a E>
Use a reference to the Entry, if present
Sourcepub fn to_grant_option(&self) -> Option<ZomeCallCapGrant>
pub fn to_grant_option(&self) -> Option<ZomeCallCapGrant>
Provides CapGrantEntry if it exists
same as as_option but handles cap grants anything other tha RecordEntry::Present for a Entry::CapGrant returns None
If no entry is available, return Hidden, else return Present
Sourcepub fn or_not_applicable(entry: Option<E>) -> RecordEntry<E>
pub fn or_not_applicable(entry: Option<E>) -> RecordEntry<E>
If no entry is available, return NotApplicable, else return Present
Sourcepub fn or_not_stored(entry: Option<E>) -> RecordEntry<E>
pub fn or_not_stored(entry: Option<E>) -> RecordEntry<E>
If no entry is available, return NotStored, else return Present