pub struct CounterSigningAgentState { /* private fields */ }Expand description
Every countersigning agent must sign against their chain state. The chain must be frozen until each agent decides to sign or exit the session.
Implementations
Sourceimpl CounterSigningAgentState
impl CounterSigningAgentState
Sourcepub fn new(
agent_index: u8,
chain_top: HoloHash<Action>,
action_seq: u32,
) -> CounterSigningAgentState
pub fn new( agent_index: u8, chain_top: HoloHash<Action>, action_seq: u32, ) -> CounterSigningAgentState
Constructor.
Sourcepub fn agent_index(&self) -> &u8
pub fn agent_index(&self) -> &u8
Agent index accessor.
Sourcepub fn agent_index_mut(&mut self) -> &mut u8
pub fn agent_index_mut(&mut self) -> &mut u8
Mutable agent index accessor for testing.
Sourcepub fn chain_top_mut(&mut self) -> &mut HoloHash<Action>
pub fn chain_top_mut(&mut self) -> &mut HoloHash<Action>
Mutable chain top accessor for testing.
Sourcepub fn action_seq(&self) -> &u32
pub fn action_seq(&self) -> &u32
Action seq accessor.
Sourcepub fn action_seq_mut(&mut self) -> &mut u32
pub fn action_seq_mut(&mut self) -> &mut u32
Mutable action seq accessor for testing.